import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Spin, Empty, notification, Row, Col, Pagination, Modal } from 'antd'
import { DownOutlined, UpOutlined, PlusSquareOutlined, MinusSquareOutlined } from '@ant-design/icons'

import Api from '@/api'
import Utils from '@/utils/utils.js'
import UtilsDM from '@/utils/utils-datamanage.js'
import preImg from '@/assets/img/prev.png'
import nextImg from '@/assets/img/next.png'
import MKEmitter from '@/utils/events.js'
import TimerTask from '@/utils/timer-task.js'
import asyncComponent from '@/utils/asyncComponent'
import './index.scss'

const CardItem = asyncComponent(() => import('../cardItem'))
const MainAction = asyncComponent(() => import('@/tabviews/zshare/actionList'))
const NormalHeader = asyncComponent(() => import('@/tabviews/custom/components/share/normalheader'))

class DoubleDataCard extends Component {
  static propTpyes = {
    config: PropTypes.object,        // 组件配置信息
    mainSearch: PropTypes.any,       // 外层搜索条件
  }

  state = {
    BID: '',                   // 上级ID
    BData: '',                 // 上级行数据
    config: null,              // 图表配置信息
    search: null,              // 搜索条件
    pageIndex: 1,              // 页码
    activeKey: '',             // 选中卡
    selectKeys: [],            // 多选时选中卡片
    selectedData: [],          // 选中数据，用于工具栏按钮
    loading: false,            // 数据加载状态
    card: null,                // 卡片设置
    data: null,                // 数据
    total: null,
    precards: [],
    nextcards: [],
    selected: 'false',
    opens: [],
    wrapStyle: null,
    subcard: null,
    subconfig: null
  }

  loaded = false

  UNSAFE_componentWillMount () {
    const { config } = this.props

    let _config = fromJS(config).toJS()
    let BID = ''
    let BData = ''

    if (_config.setting.supModule) {
      BData = window.GLOB.CacheData.get(_config.setting.supModule)
    } else {
      BData = window.GLOB.CacheData.get(_config.$pageId)
    }
    if (BData) {
      BID = BData.$BID || ''
    }

    let _card = null
    let precards = []
    let nextcards = []

    if (_config.wrap.controlField) {
      if (_config.wrap.controlVal) {
        _config.wrap.controlVal = _config.wrap.controlVal.split(',')
      } else {
        _config.wrap.controlVal = ['']
      }
    }

    _config.subcards.forEach(item => {
      if (item.setting.click === 'button' && !item.setting.linkbtn) {
        item.elements.forEach(ele => {
          if (ele.eleType === 'button') {
            item.setting.linkbtn = ele.uuid
          }
        })
        if (!item.setting.linkbtn) {
          item.setting.click = ''
        }
      }

      if (item.$cardType !== 'extendCard') {
        _card = item
      } else if (!_card) {
        precards.push(item)
      } else {
        nextcards.push(item)
      }
    })

    _config.subcards = null
    
    let _data = null

    let selected = 'false'
    if (_config.wrap.selected === 'always' || _config.wrap.selected === 'init' || _config.wrap.selected === 'sign') {
      selected = _config.wrap.selected
    } else {
      _config.wrap.selected = 'false'
    }

    _config.wrap.selStyle = _config.wrap.selStyle || 'active'
    _config.wrap.pagestyle = _config.wrap.pagestyle || 'page'

    _config.wrap.wrapClass =  `${_config.wrap.selStyle} ${_config.wrap.cardType || ''}`

    this.loaded = _data !== null

    let wrapStyle = null
    let subcard = fromJS(_card).toJS()
    let subconfig = fromJS(_config).toJS()

    subconfig.columns = subconfig.subColumns || []
    subconfig.setting.primaryKey = subconfig.setting.subKey

    subcard.style = subcard.backStyle
    subcard.elements = subcard.backElements
    subcard.setting = subcard.backSetting

    if (_card.setting.position === 'inner') {
      wrapStyle = {}
      Object.keys(_card.style).forEach(key => {
        if (!/^(margin|border|box)/.test(key)) return
        wrapStyle[key] = _card.style[key]
        delete _card.style[key]
      })
    }

    _config.setting.sub_field = subconfig.columns.map(col => col.field).join(',')

    this.setState({
      selected,
      precards,
      nextcards,
      data: _data,
      BID: BID || '',
      BData: BData || '',
      config: _config,
      subcard: subcard,
      subconfig: subconfig,
      wrapStyle: wrapStyle,
      card: _card,
      search: Utils.initMainSearch(_config.search),
      arr_field: _config.columns.map(col => col.field).join(','),
    }, () => {
      if (_config.setting.onload === 'true') {
        setTimeout(() => {
          this.loadData()
        }, _config.setting.delay || 0)
      }
    })
  }

  componentDidMount () {
    const { config } = this.state

    MKEmitter.addListener('reloadData', this.reloadData)
    MKEmitter.addListener('resetSelectLine', this.resetParentParam)
    MKEmitter.addListener('queryModuleParam', this.queryModuleParam)
    MKEmitter.addListener('refreshByButtonResult', this.refreshByButtonResult)
    
    if (config.timer) {
      this.timer = new TimerTask()
      this.timer.init(config.uuid, config.timer, config.timerRepeats, () => {
        this.setState({
          pageIndex: 1
        }, () => {
          this.loadData('', 'timer')
        })
      })
    }

    if (config.$cache && !this.loaded) {
      Api.getLCacheConfig(config.uuid).then(res => {
        if (!res || this.loaded) return
        let _data = res.map((item, index) => {
          if (item[config.setting.subdata]) {
            let _children = item[config.setting.subdata]

            delete item[config.setting.subdata]

            item.children = _children.map((cell, i) => {
              cell.key = i
              cell.$$uuid = cell[config.setting.subKey] || ''
              cell.$$BID = item[config.setting.primaryKey] || ''
              cell.$$BData = {...item}
              cell.$Index = i + 1 + ''

              return cell
            })
          } else {
            item.children = []
          }

          item.key = index
          item.$$uuid = item[config.setting.primaryKey] || ''
          item.$Index = index + 1 + ''

          if (config.wrap.controlField) {
            if (config.wrap.controlVal.includes(item[config.wrap.controlField])) {
              item.$disabled = true
            }
          }

          return item
        })

        this.setState({data: _data})
      })
    }
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  UNSAFE_componentWillReceiveProps (nextProps) {
    const { config } = this.state

    if (config.setting.useMSearch && nextProps.mainSearch && !is(fromJS(this.props.mainSearch), fromJS(nextProps.mainSearch))) {
      this.setState({pageIndex: 1}, () => {
        this.loadData()
      })
    }
  }

  componentWillUnmount () {
    this.setState = () => {
      return
    }
    MKEmitter.removeListener('reloadData', this.reloadData)
    MKEmitter.removeListener('resetSelectLine', this.resetParentParam)
    MKEmitter.removeListener('queryModuleParam', this.queryModuleParam)
    MKEmitter.removeListener('refreshByButtonResult', this.refreshByButtonResult)

    this.timer && this.timer.stop()
  }

  /**
   * @description 按钮执行完成后页面刷新
   * @param {*} menuId     // 菜单Id
   * @param {*} position   // 刷新位置
   * @param {*} btn        // 执行的按钮
   */
  refreshByButtonResult = (menuId, position, btn, id = '', lines) => {
    const { config, BID } = this.state

    if (config.uuid !== menuId) return

    let supModule = config.setting.supModule

    if (position === 'line') {
      if (lines && lines.length === 1) {
        this.loadLinedata(lines[0].$$uuid)
      } else {
        this.loadData(id)
      }
    } else if ((position === 'mainline' || position === 'popclose') && supModule && BID) { // 刷新源组件时，附带刷新上级行与当前组件
      MKEmitter.emit('reloadData', supModule, BID)
    } else if (!btn || btn.resetPageIndex !== 'false') {
      this.setState({
        pageIndex: 1
      }, () => {
        this.loadData(id)
      })
    } else {
      this.loadData(id)
    }

    if (position === 'popclose') { // 执行启动弹窗的按钮所选择的刷新项
      btn.$tabId && MKEmitter.emit('refreshPopButton', btn.$tabId)
    }
  }

  checkTopLine = (id) => {
    const { config, data, selected } = this.state

    if (!data || data.length === 0) {
      this.setState({
        activeKey: '',
        selectKeys: [],
        selectedData: []
      })
  
      MKEmitter.emit('resetSelectLine', config.uuid, '', '')
      return
    }

    if (selected === 'sign') {
      let index = ''
      let keys = []
      let items = []
      let last = ''
      data.forEach((item, i) => {
        if (!item.$disabled && item.selected === 'true') {
          items.push(item)
          keys.push(i)
          index = i
          last = item
        }
      })

      this.setState({
        activeKey: index,
        selectKeys: keys,
        selectedData: items
      })
  
      MKEmitter.emit('resetSelectLine', config.uuid, last ? last.$$uuid : '', last)
      return
    }

    let index = 0
    if (id) {
      index = data.findIndex(item => item.$$uuid === id)
      if (index === -1) {
        index = 0
      }
    }

    if (data[index].$disabled) {
      this.setState({
        activeKey: '',
        selectKeys: [],
        selectedData: []
      })
  
      MKEmitter.emit('resetSelectLine', config.uuid, '', '')
      return
    }

    this.setState({
      activeKey: index,
      selectKeys: [index],
      selectedData: [data[index]]
    })

    MKEmitter.emit('resetSelectLine', config.uuid, data[index].$$uuid, data[index])
  }

  checkAll = () => {
    const { config, data, selectedData } = this.state

    if (!data || data.length === 0) return
    
    if (selectedData.length === 0 || selectedData.length < data.length) {
      let index = ''
      let keys = []
      let items = []
      let last = ''

      data.forEach((item, i) => {
        if (item.$disabled) return

        items.push(item)
        keys.push(i)
        index = i
        last = item
      })

      this.setState({
        activeKey: index,
        selectKeys: keys,
        selectedData: items
      })
  
      MKEmitter.emit('resetSelectLine', config.uuid, last ? last.$$uuid : '', last)
    } else {
      this.setState({
        activeKey: '',
        selectKeys: [],
        selectedData: []
      })
  
      MKEmitter.emit('resetSelectLine', config.uuid, '', '')
    }
  }

  reloadData = (menuId, id) => {
    const { config } = this.state

    if (config.uuid !== menuId) return

    if (!id) {
      this.loadData()
    } else {
      this.loadLinedata(id)
    }
  }

  resetParentParam = (MenuID, id, data) => {
    const { config } = this.state

    if (!config.setting.supModule || config.setting.supModule !== MenuID) return
    if (id !== this.state.BID || id !== '') {
      this.setState({ BID: id, BData: data, pageIndex: 1 }, () => {
        this.loadData()
      })
    }
  }

  /**
   * @description 导出Excel时，获取页面搜索排序等参数
   */
  queryModuleParam = (menuId, callback) => {
    const { mainSearch } = this.props
    const { arr_field, config, search } = this.state

    if (config.uuid !== menuId) return

    let searches = search ? fromJS(search).toJS() : []
    if (config.setting.useMSearch && mainSearch && mainSearch.length > 0) { // 主表搜索条件
      let keys = searches.map(item => item.key.toLowerCase())
      mainSearch.forEach(item => {
        if (!keys.includes(item.key.toLowerCase())) {
          searches.push(item)
        }
      })
    }

    callback({
      arr_field: arr_field,
      orderBy: config.setting.order || '',
      search: searches,
      menuName: config.name
    })
  }

  async loadData (id, type) {
    const { mainSearch } = this.props
    const { config, arr_field, pageIndex, search, BID, BData, selected, card } = this.state

    if (config.setting.supModule && !BID && config.wrap.supKey !== 'false') { // BID 不存在时，不做查询
      this.loaded = true

      this.setState({
        activeKey: '',
        selectKeys: [],
        selectedData: [],
        pageIndex: 1,
        data: [],
        opens: [],
        total: 0,
        loading: false
      })
      
      if (selected !== 'false' || (id && config.wrap.selected !== 'false')) {
        setTimeout(() => {
          this.checkTopLine(id)
        }, 200)
        if (selected === 'init') {
          this.setState({selected: 'false'})
        }
      } else {
        MKEmitter.emit('resetSelectLine', config.uuid, '', '')
      }
      return
    }

    let searches = fromJS(search).toJS()
    if (config.setting.useMSearch && mainSearch && mainSearch.length > 0) { // 主表搜索条件
      let keys = searches.map(item => item.key.toLowerCase())
      mainSearch.forEach(item => {
        if (!keys.includes(item.key.toLowerCase())) {
          searches.push(item)
        }
      })
    }

    let requireFields = searches.filter(item => item.required && item.value === '')
    if (requireFields.length > 0) {
      return
    }

    if (type !== 'timer') {
      this.setState({
        loading: true
      })
    }

    let _orderBy = config.setting.order || ''
    let param = UtilsDM.getQueryDataParams(config.setting, arr_field, searches, _orderBy, pageIndex, config.setting.pageSize, BID)

    let result = await Api.genericInterface(param)
    if (result.status) {
      let start = 1
      if (config.setting.laypage) {
        start = config.setting.pageSize * (pageIndex - 1) + 1
      }

      this.loaded = true
      if (config.$cache && pageIndex === 1 && config.setting.onload !== 'false') {
        Api.writeCacheConfig(config.uuid, result.data || '')
      }

      if (selected !== 'false' || (id && config.wrap.selected !== 'false')) {
        setTimeout(() => {
          this.checkTopLine(id)
        }, 200)
        if (selected === 'init') {
          this.setState({selected: 'false'})
        }
      } else {
        MKEmitter.emit('resetSelectLine', config.uuid, '', '')
      }

      let data = []
      let opens = []

      if (type === 'plus') {
        let _data = (this.state.data || []).concat(result.data || [])
        data = _data.map((item, index) => {
          if (item[config.setting.subdata]) {
            let _children = item[config.setting.subdata]

            delete item[config.setting.subdata]

            item.children = _children.map((cell, i) => {
              cell.key = i
              cell.$$uuid = cell[config.setting.subKey] || ''
              cell.$$BID = item[config.setting.primaryKey] || ''
              cell.$$BData = {...item}
              cell.$Index = i + 1 + ''

              return cell
            })
          } else {
            item.children = []
          }

          item.key = index
          item.$$uuid = item[config.setting.primaryKey] || ''
          item.$$BID = BID || ''
          item.$$BData = BData || ''
          item.$Index = index + 1 + ''

          if (config.wrap.controlField) {
            if (config.wrap.controlVal.includes(item[config.wrap.controlField])) {
              item.$disabled = true
            }
          }
          
          return item
        })
      } else {
        data = result.data.map((item, index) => {
          if (item[config.setting.subdata]) {
            let _children = item[config.setting.subdata]

            delete item[config.setting.subdata]

            item.children = _children.map((cell, i) => {
              cell.key = i
              cell.$$uuid = cell[config.setting.subKey] || ''
              cell.$$BID = item[config.setting.primaryKey] || ''
              cell.$$BData = {...item}
              cell.$Index = i + 1 + ''

              return cell
            })
          } else {
            item.children = []
          }

          item.key = index
          item.$$uuid = item[config.setting.primaryKey] || ''
          item.$$BID = BID || ''
          item.$$BData = BData || ''
          item.$Index = index + start + ''

          if (config.wrap.controlField) {
            if (config.wrap.controlVal.includes(item[config.wrap.controlField])) {
              item.$disabled = true
            }
          }
          return item
        })
      }

      if (card.setting.display === 'unfold') {
        opens = data.map(item => item.key)
      } else {
        opens = []
      }

      this.setState({
        activeKey: '',
        selectKeys: [],
        opens: opens,
        selectedData: [],
        data: data,
        total: result.total,
        loading: false
      })
    } else {
      this.setState({
        loading: false
      })
      this.timer && this.timer.stop()
      if (result.ErrCode === 'N') {
        Modal.error({
          title: result.message,
        })
      } else {
        notification.error({
          top: 92,
          message: result.message,
          duration: 10
        })
      }
    }
  }

  /**
   * @description 获取单行数据
   */ 
  async loadLinedata (id) {
    const { mainSearch } = this.props
    const { config, arr_field, pageIndex, search, BID, BData } = this.state

    let searches = fromJS(search).toJS()
    if (config.setting.useMSearch && mainSearch && mainSearch.length > 0) { // 主表搜索条件
      let keys = searches.map(item => item.key.toLowerCase())
      mainSearch.forEach(item => {
        if (!keys.includes(item.key.toLowerCase())) {
          searches.push(item)
        }
      })
    }

    this.setState({
      loading: true
    })

    let _orderBy = config.setting.order || ''
    let param = UtilsDM.getQueryDataParams(config.setting, arr_field, searches, _orderBy, pageIndex, config.setting.pageSize, BID, id)

    let result = await Api.genericInterface(param)
    if (result.status) {
      let data = fromJS(this.state.data).toJS()
      if (result.data && result.data[0]) {
        let _data = result.data[0]

        try {
          data = data.map(item => {
            if (item[config.setting.primaryKey] === _data[config.setting.primaryKey]) {
              if (_data[config.setting.subdata]) {
                let _children = _data[config.setting.subdata]

                delete _data[config.setting.subdata]

                _data.children = _children.map((cell, i) => {
                  cell.key = i
                  cell.$$uuid = cell[config.setting.subKey] || ''
                  cell.$$BID = _data[config.setting.primaryKey] || ''
                  cell.$$BData = {..._data}
                  cell.$Index = i + 1 + ''

                  return cell
                })
              } else {
                _data.children = []
              }

              _data.key = item.key
              _data.$$uuid = _data[config.setting.primaryKey] || ''
              _data.$$BID = BID || ''
              _data.$$BData = BData || ''
              _data.$Index = item.$Index
              return _data
            } else {
              return item
            }
          })
        } catch (e) {
          console.warn('数据查询错误')
        }

        MKEmitter.emit('resetSelectLine', config.uuid, _data.$$uuid || '', _data)
      }

      this.setState({
        data: data,
        loading: false
      })
    } else {
      this.setState({
        loading: false
      })
      notification.error({
        top: 92,
        message: result.message,
        duration: 10
      })
    }
  }

  loadMore = () => {
    const { total, pageIndex, loading, config } = this.state

    if (loading || config.setting.pageSize * pageIndex >= total) {
      return
    }

    this.setState({
      pageIndex: pageIndex + 1
    }, () => {
      this.loadData('', 'plus')
    })
  }

  prevPage = () => {
    const { pageIndex } = this.state

    if (pageIndex === 1) return

    this.setState({
      pageIndex: pageIndex - 1
    }, () => {
      this.loadData()
    })
  }

  nextPage = () => {
    const { config, pageIndex, total } = this.state
    let _total = config.setting.pageSize * pageIndex

    if (_total >= total) return

    this.setState({
      pageIndex: pageIndex + 1
    }, () => {
      this.loadData()
    })
  }

  changePageIndex = (page) => {
    this.setState({
      pageIndex: page
    }, () => {
      this.loadData()
    })
  }

  refreshSearch = (list) => {
    this.setState({
      search: list,
      pageIndex: 1
    }, () => {
      this.loadData()
    })
  }
  
  changeCard = (index, item, subClass) => {
    const { config, selectKeys, selectedData, activeKey, opens, card } = this.state

    if (card.setting.click === 'unfold' && card.setting.clickType !== 'multi') {
      if (subClass === 'mk-unfold') {
        this.setState({opens: opens.filter(item => item !== index)})
      } else {
        this.setState({opens: [...opens, index]})
      }
    }

    if (!config.wrap.cardType) return
    if (item.$disabled) return
    
    let _selectKeys = []
    let _selectedData = []
    let _activeKey = ''
    let _item = item
    if (config.wrap.cardType === 'checkbox') {
      if (activeKey === index) {
        _selectKeys = selectKeys.filter(key => key !== index)
        _selectedData = selectedData.filter(cell => cell.key !== index)
        _activeKey = _selectKeys.slice(-1)[0]
        _item = _selectedData.slice(-1)[0] || ''
      } else if (selectKeys.indexOf(index) > -1) {
        _selectKeys = selectKeys.filter(key => key !== index)
        _selectedData = selectedData.filter(cell => cell.key !== index)
        _activeKey = activeKey
        _item = _selectedData.filter(cell => cell.key === activeKey)[0] || ''
      } else {
        _selectKeys = [...selectKeys, index]
        _selectedData = [...selectedData, item]
        _activeKey = index
      }
    } else {
      if (activeKey === index) return

      _selectedData = [item]
      _activeKey = index
    }

    this.setState({
      activeKey: _activeKey,
      selectKeys: _selectKeys,
      selectedData: _selectedData
    })

    MKEmitter.emit('resetSelectLine', config.uuid, (_item ? _item.$$uuid : ''), _item)
  }

  changeUnfold = (e, i, subClass) => {
    const { opens } = this.state

    e.stopPropagation()

    if (subClass === 'mk-disabled') return

    if (subClass === 'mk-unfold') {
      this.setState({opens: opens.filter(item => item !== i)})
    } else {
      this.setState({opens: [...opens, i]})
    }
  }

  onDoubleClick = (i, subClass) => {
    const { opens, card } = this.state

    if (card.setting.click !== 'unfold' || card.setting.clickType !== 'multi') return

    if (subClass === 'mk-unfold') {
      this.setState({opens: opens.filter(item => item !== i)})
    } else {
      this.setState({opens: [...opens, i]})
    }
  }

  render() {
    const { config, precards, nextcards, loading, data, pageIndex, total, card, activeKey, BID, BData, selectedData, selectKeys, subcard, subconfig, wrapStyle, opens } = this.state

    if (config.wrap.empty === 'hidden' && (!data || data.length === 0)) return null

    let _total = 0
    let switchable = false
    if (config.wrap.pagestyle === 'switch' && config.pageable && config.setting.laypage && total > config.setting.pageSize && data) {
      _total = config.setting.pageSize * pageIndex
      switchable = true
    }

    let extendData = {$$BID: BID, $$BData: BData, $$selectedData: selectedData, $$type: 'extendCard'}

    if (data && data[0]) {
      extendData = {...extendData, ...data[0]}
    }

    let checkAll = ''
    let mainBox = ''
    if (config.wrap.selStyle && config.wrap.selStyle.indexOf('check') > -1) {
      if (selectedData.length > 0) {
        checkAll = selectedData.length < data.length ? ' half' : ' whole'
      }
      if (card.setting.controlIcon === 'left') {
        checkAll += ' mk-extend-icon'
      }
    } else if (card.setting.display !== 'default' && card.setting.controlIcon === 'left') {
      mainBox = 'flex-card '
    }

    return (
      <div className="double-data-card-box" id={'anchor' + config.uuid} style={config.style}>
        {loading ?
          <div className="loading-mask">
            {data ? <div className="ant-spin-blur"></div> : null}
            <Spin />
          </div> : null
        }
        <NormalHeader config={config} BID={BID} refresh={this.refreshSearch} />
        {config.action && config.action.length > 0 ?
          <MainAction
            BID={BID}
            BData={BData}
            setting={config.setting}
            actions={config.action}
            columns={config.columns}
            selectedData={selectedData}
          /> : null
        }
        <div className={`data-zoom ${config.wrap.wrapClass}`}>
          {switchable ? <div className={'prev-page ' + (pageIndex === 1 ? 'disabled' : '')} onClick={this.prevPage}><div><div><img src={preImg} alt=""/></div></div></div> : null}
          <Row className={'card-row-list '}>
            {precards.map((item, index) => (
              <Col key={'pre' + index} className="extend-card" span={item.setting.width || 6}>
                <CardItem card={item} cards={config} data={extendData}>
                  {item.setting.checkAll === 'show' ? <span onClick={this.checkAll} className={'circle-select' + checkAll}></span> : null}
                </CardItem>
              </Col>
            ))}
            {data && data.map((item, index) => {
              let className = 'card-item-wrap mk-card ' + mainBox
              let subClass = 'mk-unfold'
              let unfold = true

              if (item.$disabled) {
                className = 'mk-disabled ' + mainBox
              } else if (activeKey === index) {
                className += 'active'
              } else if (selectKeys.indexOf(index) > -1) {
                className += 'selected'
              }

              if (card.setting.display !== 'default') {
                if (item.children.length === 0) {
                  subClass = 'mk-disabled'
                  unfold = false
                } else {
                  subClass = opens.indexOf(index) > -1 ? 'mk-unfold' : 'mk-collapse'
                  unfold = opens.indexOf(index) > -1
                }
              }

              return (
                <Col key={index} span={card.setting.width}>
                  <div className={className} style={wrapStyle}>
                    <CardItem card={card} cards={config} data={item} onDoubleClick={() => this.onDoubleClick(index, subClass)} onClick={() => {this.changeCard(index, item, subClass)}}>
                      <span className="circle-select"></span>
                      {card.setting.controlIcon === 'left' ? (!unfold ? <PlusSquareOutlined className={subClass} onClick={(e) => this.changeUnfold(e, index, subClass)}/> : <MinusSquareOutlined className={subClass} onClick={(e) => this.changeUnfold(e, index, subClass)}/>) : null}
                      {card.setting.controlIcon === 'right' ? <UpOutlined className={subClass} onClick={(e) => this.changeUnfold(e, index, subClass)}/> : null}
                    </CardItem>
                    <div className={'sub-card-wrap ' + subClass + (config.wrap.parity === 'true' ? ' mk-parity-bg' : '')}>
                      {item.children.map((cell, index) => <Col key={'sub' + index} span={subcard.setting.width || 24}>
                        <CardItem card={subcard} cards={subconfig} data={cell} />
                      </Col>)}
                    </div>
                  </div>
                </Col>
              )
            })}
            {nextcards.map((item, index) => (
              <Col key={'next' + index} className="extend-card" span={item.setting.width || 6}>
                <CardItem card={item} cards={config} data={extendData}>
                  {item.setting.checkAll === 'show' ? <span onClick={this.checkAll} className={'circle-select' + checkAll}></span> : null}
                </CardItem>
              </Col>
            ))}
          </Row>
          {switchable ? <div className={'prev-page ' + (total <= _total ? 'disabled' : '')} onClick={this.nextPage}><div><div><img src={nextImg} alt=""/></div></div></div> : null}
          {precards.length === 0 && nextcards.length === 0 && (!data || data.length === 0) ? <Empty description={false}/> : null}
        </div>
        {config.wrap.pagestyle === 'page' && config.setting.laypage && data ? <Pagination size="small" total={total} showTotal={t => `共 ${t} 条`} pageSize={config.setting.pageSize} onChange={this.changePageIndex} current={pageIndex}/> : null}
        {config.wrap.pagestyle === 'more' && config.setting.laypage && data && data.length > 0 ? <div className={'mk-more' + (config.setting.pageSize * pageIndex >= total ? ' disabled' : '')} onClick={this.loadMore}>查看更多<DownOutlined/></div> : null}
      </div>
    )
  }
}

export default DoubleDataCard